@@ -1,13 +1,13 @@
-import logging
-
 import kubernetes
+from openshift.dynamic.exceptions import NotFoundError
+from urllib3.exceptions import ProtocolError
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.logger import get_logger
+from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_logger(name=__name__)
 
 
 class DaemonSet(NamespacedResource):
@@ -17,7 +17,7 @@ class DaemonSet(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.APPS
 
-    def wait_until_deployed(self, timeout=TIMEOUT_4MINUTES):
+    def wait_until_deployed(self, timeout=TIMEOUT):
         """
         Wait until all Pods are deployed and ready.
 
@@ -31,8 +31,8 @@ class DaemonSet(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -47,20 +47,27 @@ class DaemonSet(NamespacedResource):
                 ):
                     return
 
-    def delete(self, wait=False, timeout=TIMEOUT_4MINUTES, body=None):
+    def delete(self, wait=False, timeout=TIMEOUT):
         """
         Delete Daemonset
 
         Args:
             wait (bool): True to wait for Daemonset to be deleted.
             timeout (int): Time to wait for resource deletion
-            body (dict): Content to send for delete()
 
         Returns:
             bool: True if delete succeeded, False otherwise.
         """
-        super().delete(
-            wait=wait,
-            timeout=timeout,
-            body=kubernetes.client.V1DeleteOptions(propagation_policy="Foreground"),
-        )
+        try:
+            res = self.api().delete(
+                name=self.name,
+                namespace=self.namespace,
+                body=kubernetes.client.V1DeleteOptions(propagation_policy="Foreground"),
+            )
+        except NotFoundError:
+            return False
+
+        LOGGER.info(f"Delete {self.name}")
+        if wait and res:
+            return self.wait_deleted(timeout=timeout)
+        return res
